use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Adam
DateTime
David
Golden
Gregoire
Ken
Kennedy
Nigel
Ovid
Tiny
Williams
adamk
curtis_ovid_poe
dagolden
designator
lib
nigelg
ymdhms
